Installation
============

You can install the Acellera-ATM package via conda.

.. code-block:: bash
    :linenos:

    conda create -n atm -y
    conda activate atm
    conda install acellera-atm python=3.10 -c acellera -c conda-forge
